@@ -3,10 +3,13 @@ from .skeleton import (
   ShardedSkeletonMergeTask
 )
 from .mesh import (
-  MeshTask, MeshManifestTask, 
+  MeshTask, MeshManifestPrefixTask, 
+  MeshManifestFilesystemTask,
   GrapheneMeshTask, MeshSpatialIndex,
   MultiResUnshardedMeshMergeTask,
   MultiResShardedMeshMergeTask,
+  MultiResShardedFromUnshardedMeshMergeTask,
+  TransferMeshFilesTask,
 )
 from .image import (
   HyperSquareConsensusTask, #HyperSquareTask,
